translate.misc.ini.LineContainer

Package translate :: Package misc :: Module ini :: Class LineContainer |
[hide private]
[frames] | no frames]

# Class LineContainer

source code

Instance Methods | [hide private]
__init__(self, d=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
add(self, x) | source code
extend(self, x) | source code
get_name(self) | source code
set_name(self, data) | source code
get_value(self) | source code
set_value(self, data) | source code
__str__(self) str(x) | source code
finditer(self, key) | source code
find(self, key) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
| name
| value
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, d=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

Property Details | [hide private]

### name Get Method: get_name(self) Set Method: set_name(self, data)

### value Get Method: get_value(self) Set Method: set_value(self, data)